@@ -192,7 +192,7 @@ apollo_nl <- function(nl_settings, functionality){
             nestAbove <- setNames(sapply(nestAbove, function(x) if(length(x)==1) return('Inf') else x[2]) ,
                                   sapply(nestAbove, '[', 1))
             # Printing graphical representation of the tree, using recursive function
-            apollo_print(paste0('Nesting structure for ', toupper(inputs$modeltype), ' model component ', 
+            apollo_print(paste0('Nesting structure for ', toupper(inputs$modelType), ' model component ', 
                                 ifelse(inputs$componentName=='model', '', inputs$componentName), ':'))
             print_tree_level = function(nlStructure, component, preceding_nest_layer, space){
               if(preceding_nest_layer!=0) space=c(space,"  |")
